@@ -76,6 +76,7 @@ pub(crate) fn handlers() -> impl Fn(Invoke) -> bool + Send + Sync + 'static {
         environment::config::environment_project_view_mode,
         environment::config::environment_set_project_view_mode,
         environment::config::environment_set_unity_hub_access_method,
+        environment::config::environment_set_template_favorite,
         environment::projects::environment_projects,
         environment::projects::environment_add_project_with_picker,
         environment::projects::environment_remove_project_by_path,
@@ -180,6 +181,7 @@ pub(crate) fn export_ts() {
             environment::config::environment_project_view_mode,
             environment::config::environment_set_project_view_mode,
             environment::config::environment_set_unity_hub_access_method,
+            environment::config::environment_set_template_favorite,
             environment::projects::environment_projects,
             environment::projects::environment_add_project_with_picker,
             environment::projects::environment_remove_project_by_path,
@@ -450,7 +452,7 @@ struct TauriBasePackageInfo {
     name: String,
     display_name: Option<String>,
     description: Option<String>,
-    aliases: Vec<String>,
+    keywords: Vec<String>,
     version: TauriVersion,
     unity: Option<(u16, u8)>,
     changelog_url: Option<String>,
@@ -466,7 +468,9 @@ impl TauriBasePackageInfo {
             name: package.name().to_string(),
             display_name: package.display_name().map(|v| v.to_string()),
             description: package.description().map(|v| v.to_string()),
-            aliases: package.aliases().iter().map(|v| v.to_string()).collect(),
+            keywords: (package.aliases().iter().chain(package.keywords()))
+                .map(|v| v.to_string())
+                .collect(),
             version: package.version().into(),
             unity: package.unity().map(|v| (v.major(), v.minor())),
             changelog_url: package.changelog_url().map(|v| v.to_string()),
